@@ -10,18 +10,54 @@ use Config::Tiny;
 
 use Date::Simple;
 
-use Hash::FieldHash ':all';
-
 use Lingua::EN::StopWordList;
 use Lingua::EN::StopWords;
 use Lingua::StopWords;
 
+use Moo;
+
 use Text::Xslate 'mark_raw';
 
-fieldhash my %html_config   => 'html_config';
-fieldhash my %module_config => 'module_config';
+use Types::Standard qw/Any Str/;
 
-our $VERSION = '1.01';
+has html_config =>
+(
+	default  => sub{return ''},
+	is       => 'rw',
+	isa      => Any,
+	required => 0,
+);
+
+has module_config =>
+(
+	default  => sub{return ''},
+	is       => 'rw',
+	isa      => Any,
+	required => 0,
+);
+
+has os_version =>
+(
+	default  => sub{return '! Debian'},
+	is       => 'rw',
+	isa      => Str,
+	required => 0,
+);
+
+our $VERSION = '1.03';
+
+# --------------------------------------------------
+
+sub BUILD
+{
+	my($self)   = @_;
+	my($config) = Benchmark::Featureset::StopwordLists::Config -> new;
+
+	$self -> html_config($config -> config);
+	$self -> module_config(Config::Tiny -> read('config/module.list.ini') );
+	$self -> os_version($config -> os_version);
+
+} # End of BUILD.
 
 # ------------------------------------------------
 
@@ -36,7 +72,7 @@ sub _build_environment
 	push @environment,
 	{left => 'Author', right => mark_raw(qq|<a href="http://savage.net.au/">Ron Savage</a>|)},
 	{left => 'Date',   right => Date::Simple -> today},
-	{left => 'OS',     right => 'Debian V 6.0.4'},
+	{left => 'OS',     right => $self -> os_version},
 	{left => 'Perl',   right => $Config{version} };
 
 	return \@environment;
@@ -113,7 +149,7 @@ sub _build_module_list
 		}
 		elsif ($module eq 'Lingua::StopWords')
 		{
-			$word_list = [sort keys Lingua::StopWords::getStopWords('en')];
+			$word_list = [sort keys %{Lingua::StopWords::getStopWords('en')}];
 		}
 
 		$word_list{$module} = [@$word_list];
@@ -228,19 +264,6 @@ sub _build_word_lists
 
 # --------------------------------------------------
 
-sub _init
-{
-	my($self, $arg)      = @_;
-	$$arg{html_config}   = Benchmark::Featureset::StopwordLists::Config -> new -> config;
-	$$arg{module_config} = Config::Tiny -> read('config/module.list.ini');
-	$self                = from_hash($self, $arg);
-
-	return $self;
-
-} # End of _init.
-
-# --------------------------------------------------
-
 sub log
 {
 	my($self, $level, $s) = @_;
@@ -251,18 +274,6 @@ sub log
 
 } # End of log.
 
-# --------------------------------------------------
-
-sub new
-{
-	my($class, %arg) = @_;
-	my($self)        = bless {}, $class;
-	$self            = $self -> _init(\%arg);
-
-	return $self;
-
-}	# End of new.
-
 # ------------------------------------------------
 
 sub run
@@ -364,7 +375,7 @@ or:
 
 =head2 The Configuration File
 
-All that remains is to tell L<Benchmark::Featureset::StopwordLists> your values for some options.
+All that remains is to tell L<Benchmark::Featureset::StopWwordLists> your values for some options.
 
 For that, see config/.htbenchmark.featureset.stopwordlists.conf.
 
@@ -446,7 +457,7 @@ And another set of module comparison reviews, by Ron Savage, is L<here|http://sa
 
 =head1 Machine-Readable Change Log
 
-The file CHANGES was converted into Changelog.ini by L<Module::Metadata::Changes>.
+The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
 
 =head1 Version Numbers
 
@@ -458,6 +469,10 @@ Email the author, or log a bug on RT:
 
 L<https://rt.cpan.org/Public/Dist/Display.html?Name=Benchmark::Featureset::StopwordLists>.
 
+=head1 Repository
+
+L<https://github.com/ronsavage/Benchmark-Featureset-StopwordLists.git>.
+
 =head1 Author
 
 L<Benchmark::Featureset::StopwordLists> was written by Ron Savage I<E<lt>ron@savage.net.auE<gt>> in 2012.
