@@ -6,43 +6,81 @@ use warnings;
 use Config::Tiny;
 
 use File::HomeDir;
+use File::Slurp;
 
-use Hash::FieldHash ':all';
+use Moo;
 
 use Path::Class;
 
-fieldhash my %config           => 'config';
-fieldhash my %config_file_path => 'config_file_path';
-fieldhash my %section          => 'section';
+use Types::Standard qw/Any HashRef Str/;
 
-our $VERSION = '1.01';
+has config =>
+(
+	default  => sub{return ''},
+	is       => 'rw',
+	isa      => Any,
+	required => 0,
+);
+
+has config_file_path =>
+(
+	default  => sub{return ''},
+	is       => 'rw',
+	isa      => Any,
+	required => 0,
+);
+
+has os_version =>
+(
+	default  => sub{return '! Debian'},
+	is       => 'rw',
+	isa      => Str,
+	required => 0,
+);
+
+has section =>
+(
+	default  => sub{return ''},
+	is       => 'rw',
+	isa      => Str,
+	required => 0,
+);
+
+our $VERSION = '1.03';
 
 # -----------------------------------------------
 
-sub init
+sub BUILD
 {
-	my($self, $arg) = @_;
-
-	return from_hash($self, $arg);
-
-} # End of init.
-
-# -----------------------------------------------
-
-sub new
-{
-	my($class, %arg) = @_;
-    my($self)        = bless {}, $class;
-
-	$self -> init(\%arg);
+	my($self) = @_;
 
 	my($path) = Path::Class::file(File::HomeDir -> my_dist_config('Benchmark-Featureset-StopwordLists'), '.htbenchmark.featureset.stopwordlists.conf');
 
 	$self -> read($path);
 
-    return $self;
+	$self -> get_os_version;
 
-} # End of new.
+} # End of BUILD.
+
+# -----------------------------------------------
+
+sub get_os_version
+{
+	my($self) = @_;
+	my($path) = Path::Class::file('/etc/debian_version');
+
+	my($os_version);
+
+	if (-f $path)
+	{
+		$os_version = 'Debian V ' . read_file($path);
+
+		chomp($os_version);
+
+		$self -> os_version($os_version);
+	}
+
+} # End of get_os_version.
 
 # -----------------------------------------------
 
@@ -134,6 +172,10 @@ Email the author, or log a bug on RT:
 
 L<https://rt.cpan.org/Public/Dist/Display.html?Name=Benchmark::Featureset::StopwordLists>.
 
+=head1 Repository
+
+L<https://github.com/ronsavage/Benchmark-Featureset-StopwordLists.git>.
+
 =head1 Author
 
 L<Benchmark::Featureset::StopwordLists> was written by Ron Savage I<E<lt>ron@savage.net.auE<gt>> in 2012.
